@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2005, 2007-2012, 2014-2016 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -283,7 +282,7 @@ frm (char *mailbox_name)
               "Folder contains XXX messages."
 
 	      Leave it as it is unless your language requires to reorder
-	      the parts of speach in the message
+	      the parts of speech in the message
 	  */
 	  mu_printf (_("."));
 	}
