@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -111,11 +111,10 @@ extern mu_record_t mu_imaps_record;
 /* Remote Mailbox POP3, pop://  */
 extern mu_record_t mu_pop_record;
 extern mu_record_t mu_pops_record;
-/* Remote newsgroup NNTP, nntp://  */
-extern mu_record_t mu_nntp_record;
 
 /* Local Mailbox Unix Mailbox, "mbox:"  */
 extern mu_record_t mu_mbox_record;
+
 /* Local MH, "mh:" */
 extern mu_record_t mu_mh_record;
 /* Maildir, "maildir:" */
@@ -126,7 +125,6 @@ extern mu_record_t mu_maildir_record;
 #define MU_MBOX_PRIO        300 
 #define MU_MAILDIR_PRIO     400 
 #define MU_MH_PRIO          500
-#define MU_NNTP_PRIO        600
 #define MU_PATH_PRIO        1000
   
 #define MU_SMTP_PRIO        10000
@@ -168,7 +166,6 @@ extern mu_record_t mu_dotmail_record;
   mu_registrar_record (mu_pops_record);\
   mu_registrar_record (mu_imap_record);\
   mu_registrar_record (mu_imaps_record);\
-  mu_registrar_record (mu_nntp_record);\
 } while (0)
 
 #define mu_register_all_mailer_formats() do {\
@@ -178,9 +175,7 @@ extern mu_record_t mu_dotmail_record;
   mu_registrar_record (mu_prog_record);\
 } while (0)
 
-#define mu_register_extra_formats() do {\
-  mu_registrar_record (mu_nntp_record);\
-} while (0)
+#define mu_register_extra_formats()
 
 #define mu_register_all_formats() do {\
   mu_register_all_mbox_formats ();\
