@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ typedef int function_t (int, char **);
 #define EF_REG    0x00    /* Regular command */
 #define EF_FLOW   0x01    /* Flow control command */
 #define EF_SEND   0x02    /* Send command */
-#define EF_HIDDEN 0x04    /* Hiddent command */
+#define EF_HIDDEN 0x04    /* Hidden command */
   
 typedef struct compose_env
 {
@@ -306,6 +306,7 @@ int mail_touch (int argc, char **argv);
 int mail_unalias (int argc, char **argv);
 int mail_undelete (int argc, char **argv);
 int mail_unfold (int argc, char **argv);
+int mail_unread (int argc, char **argv);
 int mail_unset (int argc, char **argv);
 int mail_version (int argc, char **argv);
 int mail_visual (int argc, char **argv);
