@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2003, 2005, 2007, 2010-2012, 2014-2016 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -69,7 +68,7 @@ mail_next (int argc, char **argv)
       int rc = msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &list);
       if (!rc)
 	{
-	  n = list->msg_part[0];
+	  n = msgset_msgno (list);
 	  msgset_free (list);
 	  if (util_get_message (mbox, n, &msg))
 	    return 1;
