@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2003, 2007, 2009-2012, 2014-2017 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -104,17 +103,20 @@ capa_implementation (const char *name, struct pop3d_session *session)
     pop3d_outf ("%s %s\n", name, PACKAGE_STRING);
 }
 
-#ifdef WITH_TLS
 static void
 capa_stls (const char *name, struct pop3d_session *session)
 {
-  if ((session->tls == tls_ondemand || session->tls == tls_required)
-      && tls_available && tls_done == 0)
-    pop3d_outf ("%s\n", name);
+  switch (session->tls_mode)
+    {
+    case tls_ondemand:
+    case tls_required:
+      pop3d_outf ("%s\n", name);
+      break;
+      
+    default:
+      break;
+    }
 }
-#else
-# define capa_stls NULL
-#endif /* WITH_TLS */
 
 static void
 capa_user (const char *name, struct pop3d_session *session)
