@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2005, 2007, 2009, 2010 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifndef _READMSG_H
 #define _READMSG_H
@@ -45,15 +42,26 @@
 #include <mailutils/filter.h>
 #include <mailutils/registrar.h>
 #include <mailutils/stream.h>
+#include <mailutils/stdstream.h>
 #include <mailutils/url.h>
 #include <mailutils/nls.h>
 #include <mailutils/tls.h>
 #include <mailutils/error.h>
 #include <mailutils/envelope.h>
-#include <mailutils/argcv.h>
-#include <mailutils/mutil.h>
+#include <mailutils/wordsplit.h>
+#include <mailutils/datetime.h>
+#include <mailutils/iterator.h>
+#include <mailutils/assoc.h>
 
 int msglist (mu_mailbox_t mbox, int show_all, int argc, char **argv, int **set, int *n);
 
+void *pattern_init (char const *pattern);
+int pattern_match (void *pat, char const *str);
+void pattern_free (void *pat);
+
+int message_body_stream (mu_message_t msg, int unix_header,
+			 char const *charset,
+			 mu_stream_t *pstr);
+
 #endif
 
